==> kadu_0.11.2.orig.tar.bz2: kadu-0.11.2/plugins/mediaplayer/translations/mediaplayer_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>@default</name>
    <message>
        <source>Syntax: %t - song title,
%a - album, %r - artist, %f - file name,
%l - song length (MM:SS), %c - current song position (MM:SS),
%p - percents of played song, %n - player name, %v - player version
</source>
        <translation>Skladba: %t - název
%a - album, %r - umělec, %f - název souboru
%l - délka písně (MM:SS), %c - současná poloha písně (MM:SS)
%p - přehrané procento z písně, %n - název přehrávače, %v - verze přehrávače</translation>
    </message>
    <message>
        <source>Pseudo-OSD for MediaPlayer</source>
        <translation>Nepravé zobrazení textu na obrazovce (OSD) pro MediaPlayer</translation>
    </message>
    <message>
        <source>MediaPlayer</source>
        <translation>MediaPlayer</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>MediaPlayer message format for chat windows</source>
        <translation>Formát zprávy MediaPlayeru pro okno s rozhovorem</translation>
    </message>
    <message>
        <source>MediaPlayer statuses in description</source>
        <translation>Popis stavu MediaPlayeru</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Nahradit</translation>
    </message>
    <message>
        <source>MediaPlayer description format</source>
        <translation>Formát popisu MediaPlayeru</translation>
    </message>
    <message>
        <source>Here specify format which will replace &apos;#{player}&apos; tag when you will use it in description while setting status.</source>
        <translation>Zde zadejte formátování, které nahradí značku &apos;#{player}&apos;, když ji použijete v popisu při nastavování stavu.</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Povolit</translation>
    </message>
    <message>
        <source>Signatures to cut</source>
        <translation>Podpisy k vyjmutí</translation>
    </message>
    <message>
        <source>Crap to cut</source>
        <translation>Blbost k vyjmutí</translation>
    </message>
    <message>
        <source>Enable pseudo-OSD</source>
        <translation>Povolit nepravé zobrazení textu na obrazovce (OSD)</translation>
    </message>
    <message>
        <source>Enables pseudo-OSD done by Kadu hints. Shows currently played title in hint.</source>
        <translation>Povolí nepravé zobrazení textu na obrazovce (OSD) udělané z rad Kadu. Ukáže v radě nyní přehrávanou skladbu.</translation>
    </message>
    <message>
        <source>Enable MediaPlayer keyboard shortcuts in chat window</source>
        <translation>Povolit klávesové zkratky pro obsluhu přehrávacího programu v okně s rozhovorem</translation>
    </message>
    <message>
        <source>Put statuses switch to dock menu</source>
        <translation>Přepínač pro popis stavu v okně panelu</translation>
    </message>
    <message>
        <source>Enable this to put MediaPlayer statuses switch into docked icon menu.</source>
        <translation>Povolte, když hodláte popisy stavu zapínat a vypínat přes nabídku symbolu v oznamovací oblasti panelu.</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Obecná nastavení</translation>
    </message>
    <message>
        <source>Signature Cutting</source>
        <translation>Vyjmutí podpisu</translation>
    </message>
    <message>
        <source>Shall I cut this crap?</source>
        <translation>Mám vyjmout tuhle blbost?</translation>
    </message>
    <message>
        <source>Other Settings</source>
        <translation>Jiná nastavení</translation>
    </message>
    <message>
        <source>Add in the Front</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add at the Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replace &apos;#{player}&apos; Tag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>With this option enabled you&apos;ll be able to control
your MediaPlayer in chat window by keyboard shortcuts:
Control+ Enter/Backspace/Left/Right/Up/Down.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>With this option enabled you&apos;ll be able to control
your MediaPlayer in chat window by keyboard shortcuts:
Win+ Enter/Backspace/Left/Right/Up/Down.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaPlayer</name>
    <message>
        <source>Put formated string</source>
        <translation>Vložit formátovaný text</translation>
    </message>
    <message>
        <source>Put song title</source>
        <translation>Vložit název písně</translation>
    </message>
    <message>
        <source>Put song file name</source>
        <translation>Vložit název souboru písně</translation>
    </message>
    <message>
        <source>Send all playlist titles</source>
        <translation>Poslat všechny skladby v seznamu skladeb</translation>
    </message>
    <message>
        <source>Send all playlist files</source>
        <translation>Poslat všechny soubory v seznamu skladeb</translation>
    </message>
    <message>
        <source>Enable MediaPlayer statuses</source>
        <translation>Povolit popisy stavů MediaPlayeru</translation>
    </message>
    <message>
        <source>MediaPlayer</source>
        <translation>MediaPlayer</translation>
    </message>
    <message>
        <source>%1 isn&apos;t running!</source>
        <translation>%1 - neběží!</translation>
    </message>
    <message>
        <source>You&apos;re trying to send %1 entries of %2 playlist.&lt;br&gt;It will be split and sent in few messages&lt;br&gt;Are you sure to do that?</source>
        <translation>Pokoušíte se poslat %1 záznamy seznamu skladeb %2.&lt;br&gt;Bude rozdělen a poslán ve více zprávách.&lt;br&gt;Má se pokračovat?</translation>
    </message>
    <message>
        <source>Playback stopped.</source>
        <translation>Přehrávání zastaveno.</translation>
    </message>
    <message>
        <source>Player turned off.</source>
        <translation>Přehrávač vypnut.</translation>
    </message>
    <message>
        <source>Enable MediaPlayer Statuses</source>
        <translation>Povolit popisy stavů MediaPlayeru</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Přehrát</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zastavit</translation>
    </message>
    <message>
        <source>Previous Track</source>
        <translation>Předchozí skladba</translation>
    </message>
    <message>
        <source>Next Track</source>
        <translation>Další skladba</translation>
    </message>
    <message>
        <source>Volume Up</source>
        <translation>Zvýšit hlasitost</translation>
    </message>
    <message>
        <source>Volume Down</source>
        <translation>Snížit hlasitost</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>More than 1/10 of titles you&apos;re trying to send are empty.&lt;br&gt;Perhaps %1 hasn&apos;t read all titles yet, give its some more time.&lt;br&gt;Do you want to send playlist anyway?</source>
        <translation>Více než 1/10 skladeb, jež se pokoušíte poslat, je prázdná.&lt;br&gt;Možná %1 ještě nepřečetl všechny skladby, dejte tomu ještě nějaký čas navíc.&lt;br&gt;Přesto chcete seznam skladeb poslat?</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pozastavit</translation>
    </message>
    <message>
        <source>Player isn&apos;t running!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/mediaplayer/translations/mediaplayer_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Syntax: %t - song title,
%a - album, %r - artist, %f - file name,
%l - song length (MM:SS), %c - current song position (MM:SS),
%p - percents of played song, %n - player name, %v - player version
</source>
        <translation>Skladba: %t - název
%a - album, %r - umělec, %f - název souboru
%l - délka písně (MM:SS), %c - současná poloha písně (MM:SS)
%p - přehrané procento z písně, %n - název přehrávače, %v - verze přehrávače</translation>
    </message>
    <message>
        <source>Pseudo-OSD for MediaPlayer</source>
        <translation>Nepravé zobrazení textu na obrazovce (OSD) pro MediaPlayer</translation>
    </message>
    <message>
        <source>MediaPlayer</source>
        <translation>MediaPlayer</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>MediaPlayer message format for chat windows</source>
        <translation>Formát zprávy MediaPlayeru pro okno s rozhovorem</translation>
    </message>
    <message>
        <source>MediaPlayer statuses in description</source>
        <translation>Popis stavu MediaPlayeru</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Nahradit</translation>
    </message>
    <message>
        <source>MediaPlayer description format</source>
        <translation>Formát popisu MediaPlayeru</translation>
    </message>
    <message>
        <source>Here specify format which will replace &apos;#{player}&apos; tag when you will use it in description while setting status.</source>
        <translation>Zde zadejte formátování, které nahradí značku &apos;#{player}&apos;, když ji použijete v popisu při nastavování stavu.</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Povolit</translation>
    </message>
    <message>
        <source>Signatures to cut</source>
        <translation>Podpisy k vyjmutí</translation>
    </message>
    <message>
        <source>Crap to cut</source>
        <translation>Blbost k vyjmutí</translation>
    </message>
    <message>
        <source>Enable pseudo-OSD</source>
        <translation>Povolit nepravé zobrazení textu na obrazovce (OSD)</translation>
    </message>
    <message>
        <source>Enables pseudo-OSD done by Kadu hints. Shows currently played title in hint.</source>
        <translation>Povolí nepravé zobrazení textu na obrazovce (OSD) udělané z rad Kadu. Ukáže v radě nyní přehrávanou skladbu.</translation>
    </message>
    <message>
        <source>Enable MediaPlayer keyboard shortcuts in chat window</source>
        <translation>Povolit klávesové zkratky pro obsluhu přehrávacího programu v okně s rozhovorem</translation>
    </message>
    <message>
        <source>Put statuses switch to dock menu</source>
        <translation>Přepínač pro popis stavu v okně panelu</translation>
    </message>
    <message>
        <source>Enable this to put MediaPlayer statuses switch into docked icon menu.</source>
        <translation>Povolte, když hodláte popisy stavu zapínat a vypínat přes nabídku symbolu v oznamovací oblasti panelu.</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Obecná nastavení</translation>
    </message>
    <message>
        <source>Signature Cutting</source>
        <translation>Vyjmutí podpisu</translation>
    </message>
    <message>
        <source>Shall I cut this crap?</source>
        <translation>Mám vyjmout tuhle blbost?</translation>
    </message>
    <message>
        <source>Other Settings</source>
        <translation>Jiná nastavení</translation>
    </message>
    <message>
        <source>With this option enabled you'll be able to control
your MediaPlayer in chat window by keyboard shortcuts:
Control+ Enter/Backspace/Left/Right/Up/Down.</source>
        <translation>Při povolení této volby budete moci ovládat svůj
přehrávač v okně pro rozhovor klávesovými zkratkami:
Control+ Enter/Backspace/Left/Right/Up/Down.</translation>
    </message>
    <message>
        <source>With this option enabled you'll be able to control
your MediaPlayer in chat window by keyboard shortcuts:
Win+ Enter/Backspace/Left/Right/Up/Down.</source>
        <translation>Při povolení této volby budete moci ovládat svůj
přehrávač v okně pro rozhovor klávesovými zkratkami:
Win+ Enter/Backspace/Left/Right/Up/Down.</translation>
    </message>
    <message>
        <source>Add in the Front</source>
        <translation>Přidat dopředu</translation>
    </message>
    <message>
        <source>Add at the Back</source>
        <translation>Přidat dozadu</translation>
    </message>
    <message>
        <source>Replace &apos;#{player}&apos; Tag</source>
        <translation>Nahradit značku &apos;#{player}&apos;</translation>
    </message>
</context>
<context>
    <name>MediaPlayer</name>
    <message>
        <source>Put formated string</source>
        <translation>Vložit formátovaný text</translation>
    </message>
    <message>
        <source>Put song title</source>
        <translation>Vložit název písně</translation>
    </message>
    <message>
        <source>Put song file name</source>
        <translation>Vložit název souboru písně</translation>
    </message>
    <message>
        <source>Send all playlist titles</source>
        <translation>Poslat všechny skladby v seznamu skladeb</translation>
    </message>
    <message>
        <source>Send all playlist files</source>
        <translation>Poslat všechny soubory v seznamu skladeb</translation>
    </message>
    <message>
        <source>Enable MediaPlayer statuses</source>
        <translation>Povolit popisy stavů MediaPlayeru</translation>
    </message>
    <message>
        <source>MediaPlayer</source>
        <translation>MediaPlayer</translation>
    </message>
    <message>
        <source>%1 isn&apos;t running!</source>
        <translation>%1 - neběží!</translation>
    </message>
    <message>
        <source>You&apos;re trying to send %1 entries of %2 playlist.&lt;br&gt;It will be split and sent in few messages&lt;br&gt;Are you sure to do that?</source>
        <translation>Pokoušíte se poslat %1 záznamy seznamu skladeb %2.&lt;br&gt;Bude rozdělen a poslán ve více zprávách.&lt;br&gt;Má se pokračovat?</translation>
    </message>
    <message>
        <source>Playback stopped.</source>
        <translation>Přehrávání zastaveno.</translation>
    </message>
    <message>
        <source>Player turned off.</source>
        <translation>Přehrávač vypnut.</translation>
    </message>
    <message>
        <source>Enable MediaPlayer Statuses</source>
        <translation>Povolit popisy stavů MediaPlayeru</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Přehrát</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zastavit</translation>
    </message>
    <message>
        <source>Previous Track</source>
        <translation>Předchozí skladba</translation>
    </message>
    <message>
        <source>Next Track</source>
        <translation>Další skladba</translation>
    </message>
    <message>
        <source>Volume Up</source>
        <translation>Zvýšit hlasitost</translation>
    </message>
    <message>
        <source>Volume Down</source>
        <translation>Snížit hlasitost</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>More than 1/10 of titles you&apos;re trying to send are empty.&lt;br&gt;Perhaps %1 hasn&apos;t read all titles yet, give its some more time.&lt;br&gt;Do you want to send playlist anyway?</source>
        <translation>Více než 1/10 skladeb, jež se pokoušíte poslat, je prázdná.&lt;br&gt;Možná %1 ještě nepřečetl všechny skladby, dejte tomu ještě nějaký čas navíc.&lt;br&gt;Přesto chcete seznam skladeb poslat?</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pozastavit</translation>
    </message>
    <message>
        <source>Player isn&apos;t running!</source>
        <translation>Přehrávač neběží</translation>
    </message>
</context>
</TS>
